@@ -28,11 +28,11 @@ function(paths,dORb){
 		     s2<-c()
 		     s3<-c()
 		     s1<-paths
-			 m<-substr(data[i],(25+nchar(paths)+nchar(i)+1),(25+nchar(paths)+nchar(i)+2))
+			 m<-substr(data[i],(25+nchar(paths)+1),(25+nchar(paths)+2))
 			 if(substr(m,2,2)!=","){
 			     s2<-as.numeric(m)
 			 }else{
-			     s2<-substr(data[i],(25+nchar(paths)+nchar(i)+1),(25+nchar(paths)+nchar(i)+1))
+			     s2<-substr(data[i],(25+nchar(paths)+1),(25+nchar(paths)+1))
 			 }
 			 s3<-substr(data[i],(28+nchar(paths)+nchar(s2)),(nchar(data[i])-2))
 			 broad_subPathwayGraph(s1,s2,s3)
